text = """"<html><head></head><body><h3><img src="/imgs/solaren.png" width="100%" height="auto" alt="solaren"></h3>
    <h1><a href="https://www.solarenspace.com/" target="_blank" <center="">SOLAREN SPACE</a><div class="row" style="float:right;display:inline-block"><a href="https://www.solarenspace.com/" target="_blank" <center=""></a><h4>US20110204159A1 Weather management using space-based power system</h4>
    <h3><a href="https://patents.google.com/patent/US20110204159A1/en" target="_blank"></a>(LINK)
    <img src="/SOMMERFELD GOUBAU/PICS/PatentThumb/US20110204159A1.png" width="334px" height="650px">
    <a href="/BOOTSTRAP/PICS/Solaren/US_20110204159A1_WeatherManagementSpaceBasedPowerSystem.html" target="_blank">(VIEW)
    <img src="/BOOTSTRAP/PICS/Solaren/US_20110204159A1_WEATHERMANAGEMENT USING SPACE-BASED POWER SYSTEM/US_20110204159A1_WEATHERMANAGEMENT USING SPACE-BASED POWER SYSTEM-page-001.jpg" width="400" height="650px" alt="WEATHERMANAGEMENT"></a>
    </h3></div>
    <div class="row">
    <h2> Dec 8, 2010 - SOLAREN CORPORATION
    <p></p><center>Space-based power system and method of altering weather using space-born energy. The space-based power system maintains proper positioning and alignment of system components without using connecting structures. Power system elements are launched into orbit, and the free-floating power system elements are maintained in proper relative alignment, e.g., position, orientation, and shape, using a control system. Energy from the space-based power system is applied to a weather element, such as a hurricane, and alters the weather element to weaken or dissipate the weather element. The weather element can be altered by changing a temperature of a section of a weather element, such as the eye of a hurricane, changing airflows, or changing a path of the weather element.<p></p></center></h2>
    <h4>US20100224696A1
    Weather management using space-based power system</h4>
    <h3>
        <div class="column">
        <a href="https://patents.google.com/patent/US20100224696A1/en" target="_blank">(LINK) 
    <img src="/SOMMERFELD GOUBAU/PICS/PatentThumb/US20100224696A1.png" width="334px" height="650px"></a><a href="/BOOTSTRAP/PICS/Solaren/US_20100224696A1_WeatherManagementSpaceBasedPowerSystem.html" target="_blank"></a></div><a href="/BOOTSTRAP/PICS/Solaren/US_20100224696A1_WeatherManagementSpaceBasedPowerSystem.html" target="_blank">
        </a><div class="column"><a href="/BOOTSTRAP/PICS/Solaren/US_20100224696A1_WeatherManagementSpaceBasedPowerSystem.html" target="_blank">(VIEW)
    <img src="/BOOTSTRAP/PICS/Solaren/US_20100224696A1_WEATHERMANAGEMENT USING SPACE-BASED POWER SYSTEM/US_20100224696A1_WEATHERMANAGEMENT USING SPACE-BASED POWER SYSTEM-page-001.jpg" width="400" height="650px" alt="WEATHERMANAGEMENT"></a>
    </div></h3></div>
    <p>Additionally, there exists a need for a system and method that can reduce the impact of weather elements. In particular, there exists a need for a system and method to weaken, or eliminate, hurricanes, typhoons and the like, such as the hurricane 1800 off of the coast of Florida shown in FIG. 18.</p>
    Currently, there is no known system or method that effectively reduces the impact of weather elements, including large weather elements such as hurricanes and typhoons. The terms “hurricane” and “typhoon” are regionally specific names for a strong “tropical cyclone.” “Tropical cyclone” is a generic term that refers to a non-frontal synoptic scale low-pressure system over tropical or sub-tropical waters with organized convection (i.e. thunderstorm activity) and cyclonic surface wind circulation.<p></p>
    Tropical cyclones with maximum sustained surface wind speeds of less than 17 m/s (34 kt, 39 mph) are generally referred to as “tropical depressions.” Once a tropical cyclone reaches wind speeds of greater than 17 m/s (34 kt, 39 mph), they are typically called a tropical storm and assigned a name. If wind speeds reach 33 m/s (64 kt, 74 mph), then they are called various names in various regions, e.g., a “hurricane” (North Atlantic Ocean, Northeast Pacific Ocean east of the dateline, or the South Pacific Ocean east of 160E); “typhoon” (Northwest Pacific Ocean west of the dateline); “severe tropical cyclone” (Southwest Pacific Ocean west of 160E or Southeast Indian Ocean east of 90E); “severe cyclonic storm” (North Indian Ocean) and “tropical cyclone” (Southwest Indian Ocean). This specification generally refers to such storms as “hurricane” and more generally as a “weather element.”<p></p>
    </h1><h4>US_7612284
    Space-based power system</h4>
    <h3><a href="https://patents.google.com/patent/US7612284B2/en" target="_blank"> (LINK)
    <img src="/SOMMERFELD GOUBAU/PICS/PatentThumb/US7612284B2.png" width="334px" height="650px"></a> <a href="/BOOTSTRAP/PICS/Solaren/US_7612284_SpaceBasedPowerSystem.html" target="_blank">(VIEW)
    <img src="/BOOTSTRAP/PICS/Solaren/US_7612284_SPACE-BASED POWER SYSTEM/US_7612284_SPACE-BASED POWER SYSTEM-page-001.jpg" width="400" height="650px" alt="Space Based POWER SYSTEMS"></a>
    </h3>
    <p>DC electrical power generated by the solar cells 7 is converted by the RF or optical power modules 8 into a form that can be transmitted, such as RF or optical power. The RF or optical power is radiated by the RF feeds or optical emitters 9 to the RF reflector, output mirror 10 (generally reflector 10), or directly to the predetermined location. For example, the RF feeds or optical emitters 9 can be arranged in a direct radiating array or a phased array antenna 19 (FIG. 1E), thus eliminating the need for a reflector 10. Waste heat from the solar cells 7, power modules 8, and RF feeds or optical emitters 9 is radiated into space by the thermal panels 11.</p>
    The reflector 10 is constructed so that the coating or incident surface reflects power to Earth or another predetermined location or station and transmits sunlight. By transmitting sunlight 1, the photon pressure on the reflector 10 is reduced or nearly eliminated. Since the reflector 10, may be as large as the primary mirror 2, reducing photon pressure results in a significant reduction in fuel that is needed for station-keeping of the reflector 10. However, as with the primary mirror 2, the residual photon pressure, in conjunction with the selected residual mechanical stress of the coating that reflects power and transmits sunlight 1, can be used to maintain the correct shape of the reflecting surface. This arrangement can reduce the weight of the reflector 10, for example, up to about 66% or more. Alternatively, an optical mirror 10 is constructed so that the coating reflects the desired optical wavelengths and transmits unwanted solar radiation.<p></p>
    <h4>US20060201547A1
    Weather management using space-based power system</h4>
    <h3><a href="https://patents.google.com/patent/US20060201547A1/en" target="_blank"> (LINK)
    <img src="/SOMMERFELD GOUBAU/PICS/PatentThumb/US20060201547A1.png" width="334px" height="650px" alt="WEATHERMANAGEMENT"></a> <a href="/BOOTSTRAP/PICS/Solaren/US_20060201547A1_WeatherManagementSpaceBasedPowerSystem.html" target="_blank">(VIEW)
    <img src="/BOOTSTRAP/PICS/Solaren/US_20060201547A1_WEATHER MANAGEMENT USING SPACE-BASED POWER SYSTEM/US_20060201547A1_WEATHER MANAGEMENT USING SPACE-BASED POWER SYSTEM-page-001.jpg" width="400" height="650px" alt="WEATHERMANAGEMENT"></a>
    </h3>
    <p>In various embodiments, the RF energy generated in space can have a frequency of about 2 GHz to about 12 GHz and be applied to a weather element having a diameter of about 1 km to about 10 km. The amount of energy that is applied to a weather element can be about 109 watts/km2 of energy. The energy can be applied to different locations, e.g, the eye of the hurricane, typhoon, tropical cyclone, cyclonic storm or other weather element, to alter and/or dissipate the weather element. Further energy can be applied to or adjacent to weather elements, such as thunderstorms, that can form into more serious and mature weather elements. The energy can alter air flows, change the direction of the weather element and create temperature gradients or inversion layers, e.g., temperature increases of about 2° C. to about 12° C. Energy absorbing elements can be introduced into a weather element. These absorbing elements absorb RF energy and converts it to thermal energy, which is applied to the weather element to achieve these results. For example, energy absorbing elements can be aluminum oxide, plastic or other suitable RF absorbing materials. The absorbing elements can be coated to facilitate thermal energy transfer. One suitable coating is an iron oxide coating. These elements are constructed such that their surface area to mass ratio is large in order to minimize their sink rate, thereby allowing them to “float” with an air mass. The energy absorbing elements are preferably substantially buoyant with the weather element.</p>
    <h4>US20060185726A1
    Space-based power system</h4>
    <h3><a href="https://patents.google.com/patent/US20060185726A1/en" target="_blank"> (LINK)
    <img src="/SOMMERFELD GOUBAU/PICS/PatentThumb/US20060185726A1.png" width="334px" height="650px" alt="SPACE BASED POWER SYSTEMS"></a><a href="/BOOTSTRAP/PICS/Solaren/US_20060185726A1_SpaceBasedPowerSystem.html" target="_blank">(VIEW)
    <img src="/BOOTSTRAP/PICS/Solaren/US_20060185726A1_SPACE-BASED POWER SYSTEM/US_20060185726A1_SPACE-BASED POWER SYSTEM-page-001.jpg" width="400" height="650px" alt="SPACE BASED POWER SYSTEMS"></a>
    </h3>
    <p> Thus, in the illustrated embodiments, the control system makes adjustments based on communications between sensors of adjacent elements, i.e., elements that communicate with each other by reflecting or receiving sunlight or other signals. For example, the primary mirror 2, fold mirrors 4 and 5, optical module 8 and reflector 10 can all include sensors. The sensors on the mirrors 2 and 4 communicate with each other, the sensors on the mirrors 4 and 5 communicate with each other, the sensors on the mirror 5 and the optical module 8 communicate with each other, and the sensors on the optical module 8 and the reflector 10 communicate with each other. The control circuit is configured to adjust a system component based on the alignment of the previously described pairs of components. Adjustments can be made based on alignments of other numbers and combinations of system components.</p>
    <p>Thus, for example, in response to sensor data between mirrors 2 and 4, thrusters on the mirror 4 may be activated (or de-activated) to re-align the mirror 4 with respect to mirror 2. Similarly, thrusters on mirror 2 can be activated (or de-activated). After re-aligning one system component, one or more other system components can also be re-positioned to maintain proper alignment of the entire system. A monitoring system on Earth or another planet, body or station can also monitor and alter the alignment of system components.</p>
    <p>In one embodiment, a proximity control system 13 uses complementary and redundant position-measuring devices, such as stereoscopic cameras, modulated laser diodes, and lasers. For example, lasers can form a closed loop of optically coherent beams, such that a change in relative positions and orientation of the system components produce a change in the interference pattern at each of the loop's detectors. Relative motion in a system can also produce Doppler shifts of the light beams that determine direction of motion. These changes and shifts can be used to maintain the relative positions of power system components, e.g., to sub-millimeter accuracies. </p>
    <h4>US6936760B2
    Space-based power system</h4>
    <h3><a href="https://patents.google.com/patent/US6936760B2/en" target="_blank"> (LINK)
    <img src="/SOMMERFELD GOUBAU/PICS/PatentThumb/US6936760B2.png" width="334px" height="650px" alt="SPACE BASED POWER SYSTEMS"></a> <a href="/BOOTSTRAP/PICS/Solaren/US_6936760_SpaceBasedPowerSystem.html" target="_blank">(VIEW)
    <img src="/BOOTSTRAP/PICS/Solaren/US_6936760_SPACE-BASED POWER SYSTEM/US_6936760_SPACE-BASED POWER SYSTEM-page-001.jpg" width="400" height="650px" alt="SPACE BASED POWER SYSTEMS"></a>
    </h3>
    <p>In another embodiment, a space-based power system includes a plurality of power system elements in space and a control system. One or more elements of the plurality of elements are free-floating in space. The power system elements include a primary mirror, an intermediate mirror, a power module, an emitter, and a reflective mirror. The primary mirror directs sunlight to the intermediate mirror. The intermediate mirror directs sunlight to the power module, which generates direct current electricity. The emitter converts the direct current electricity into RF or optical energy, and the reflective mirror transmits the RF or optical energy to a receiver at a predetermined location. The control system includes a plurality of sensors and a plurality of displacement members. Each element in space includes a sensor and a displacement element, and the control system maintains alignment of the free-floating elements in space by selectively activating a displacement member in response to sensor data.</p>
    <a href="https://patents.justia.com/assignee/solaren-corporation" target="_blank">SOLAREN PATENTS</a>
       </body></html>"""
